==> DateTime-Locale-1.36.tar.gz: DateTime-Locale-1.36/share/yrl-CO.pl <==
{
  am_pm_abbreviated => [
    "a.\N{U+00a0}m.",
    "p.\N{U+00a0}m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-one" => "W'\N{U+00aa}' 's\N{U+1ebd}m\N{U+00e3}na' MMMM",
    "MMMMW-count-other" => "W'\N{U+00aa}' 's\N{U+1ebd}m\N{U+00e3}na' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, dd/MM/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMMEd => "E, d MMMM y",
    yMMMMd => "d MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "w'\N{U+00aa}' 's\N{U+1ebd}m\N{U+00e3}na' Y",
    "yw-count-other" => "w'\N{U+00aa}' 's\N{U+1ebd}m\N{U+00e3}na' Y",
  },
  code => "yrl-CO",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "mur",
    "mmk",
    "mms",
    "sup",
    "yuk",
    "sau",
    "mit",
  ],
  day_format_narrow => [
    "M",
    "M",
    "M",
    "S",
    "Y",
    "S",
    "M",
  ],
  day_format_wide => [
    "murakip\N{U+00ed}",
    "murak\N{U+00ed}-muk\N{U+0169}i",
    "murak\N{U+00ed}-musap\N{U+00ed}ri",
    "supap\N{U+00e1}",
    "yukuak\N{U+00fa}",
    "saur\N{U+00fa}",
    "mitu\N{U+00fa}",
  ],
  day_stand_alone_abbreviated => [
    "mur",
    "mmk",
    "mms",
    "sup",
    "yuk",
    "sau",
    "mit",
  ],
  day_stand_alone_narrow => [
    "M",
    "M",
    "M",
    "S",
    "Y",
    "S",
    "M",
  ],
  day_stand_alone_wide => [
    "murakip\N{U+00ed}",
    "murak\N{U+00ed}-muk\N{U+0169}i",
    "murak\N{U+00ed}-musap\N{U+00ed}ri",
    "supap\N{U+00e1}",
    "yukuak\N{U+00fa}",
    "saur\N{U+00fa}",
    "mitu\N{U+00fa}",
  ],
  era_abbreviated => [
    "K.s.",
    "K.a.",
  ],
  era_narrow => [
    "K.s.",
    "K.a.",
  ],
  era_wide => [
    "Kiristu sen\N{U+0169}d\N{U+00e9}",
    "Kiristu arir\N{U+00e9}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Nheengatu",
  month_format_abbreviated => [
    "ye",
    "mk",
    "ms",
    "id",
    "pu",
    "py",
    "pm",
    "ps",
    "pi",
    "yp",
    "yy",
    "ym",
  ],
  month_format_narrow => [
    "Y",
    "M",
    "M",
    "I",
    "P",
    "P",
    "P",
    "P",
    "P",
    "Y",
    "Y",
    "Y",
  ],
  month_format_wide => [
    "yep\N{U+00e9}",
    "muk\N{U+0169}i",
    "musap\N{U+00ed}ri",
    "ir\N{U+0169}d\N{U+00ed}",
    "p\N{U+00fa}",
    "p\N{U+00fa}-yep\N{U+00e9}",
    "p\N{U+00fa}-muk\N{U+0169}i",
    "p\N{U+00fa}-musap\N{U+00ed}ri",
    "p\N{U+00fa}-ir\N{U+0169}d\N{U+00ed}",
    "yep\N{U+00e9}-putima\N{U+00e3}",
    "yep\N{U+00e9}-yep\N{U+00e9}",
    "yep\N{U+00e9}-muk\N{U+0169}i",
  ],
  month_stand_alone_abbreviated => [
    "ye",
    "mk",
    "ms",
    "id",
    "pu",
    "py",
    "pm",
    "ps",
    "pi",
    "yp",
    "yy",
    "ym",
  ],
  month_stand_alone_narrow => [
    "Y",
    "M",
    "M",
    "I",
    "P",
    "P",
    "P",
    "P",
    "P",
    "Y",
    "Y",
    "Y",
  ],
  month_stand_alone_wide => [
    "yep\N{U+00e9}",
    "muk\N{U+0169}i",
    "musap\N{U+00ed}ri",
    "ir\N{U+0169}d\N{U+00ed}",
    "p\N{U+00fa}",
    "p\N{U+00fa}-yep\N{U+00e9}",
    "p\N{U+00fa}-muk\N{U+0169}i",
    "p\N{U+00fa}-musap\N{U+00ed}ri",
    "p\N{U+00fa}-ir\N{U+0169}d\N{U+00ed}",
    "yep\N{U+00e9}-putima\N{U+00e3}",
    "yep\N{U+00e9}-yep\N{U+00e9}",
    "yep\N{U+00e9}-muk\N{U+0169}i",
  ],
  name => "Nheengatu Colombia",
  native_language => "\N{U+00f1}engat\N{U+00fa}",
  native_name => "\N{U+00f1}engat\N{U+00fa} Kur\N{U+0169}biya",
  native_script => undef,
  native_territory => "Kur\N{U+0169}biya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "M1",
    "M2",
    "M3",
    "M4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "yep\N{U+00e9}s\N{U+00e1}wa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "muk\N{U+0169}isawa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "musap\N{U+00ed}risawa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "ir\N{U+0169}disawa musap\N{U+00ed}ri-yas\N{U+00ed}",
  ],
  quarter_stand_alone_abbreviated => [
    "M1",
    "M2",
    "M3",
    "M4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "yep\N{U+00e9}s\N{U+00e1}wa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "muk\N{U+0169}isawa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "musap\N{U+00ed}risawa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "ir\N{U+0169}disawa musap\N{U+00ed}ri-yas\N{U+00ed}",
  ],
  script => undef,
  territory => "Colombia",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/yrl-CO.pl <==
{
  am_pm_abbreviated => [
    "a.\N{U+202f}m.",
    "p.\N{U+202f}m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm\N{U+202f}a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-other" => "W'\N{U+00aa}' 's\N{U+1ebd}m\N{U+00e3}na' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, dd/MM/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMMEd => "E, d MMMM y",
    yMMMMd => "d MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "w'\N{U+00aa}' 's\N{U+1ebd}m\N{U+00e3}na' Y",
  },
  code => "yrl-CO",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "mur",
    "mmk",
    "mms",
    "sup",
    "yuk",
    "sau",
    "mit",
  ],
  day_format_narrow => [
    "M",
    "M",
    "M",
    "S",
    "Y",
    "S",
    "M",
  ],
  day_format_wide => [
    "murakip\N{U+00ed}",
    "murak\N{U+00ed}-muk\N{U+0169}i",
    "murak\N{U+00ed}-musap\N{U+00ed}ri",
    "supap\N{U+00e1}",
    "yukuak\N{U+00fa}",
    "saur\N{U+00fa}",
    "mitu\N{U+00fa}",
  ],
  day_stand_alone_abbreviated => [
    "mur",
    "mmk",
    "mms",
    "sup",
    "yuk",
    "sau",
    "mit",
  ],
  day_stand_alone_narrow => [
    "M",
    "M",
    "M",
    "S",
    "Y",
    "S",
    "M",
  ],
  day_stand_alone_wide => [
    "murakip\N{U+00ed}",
    "murak\N{U+00ed}-muk\N{U+0169}i",
    "murak\N{U+00ed}-musap\N{U+00ed}ri",
    "supap\N{U+00e1}",
    "yukuak\N{U+00fa}",
    "saur\N{U+00fa}",
    "mitu\N{U+00fa}",
  ],
  era_abbreviated => [
    "K.s.",
    "K.a.",
  ],
  era_narrow => [
    "K.s.",
    "K.a.",
  ],
  era_wide => [
    "Kiristu sen\N{U+0169}d\N{U+00e9}",
    "Kiristu arir\N{U+00e9}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Nheengatu",
  month_format_abbreviated => [
    "ye",
    "mk",
    "ms",
    "id",
    "pu",
    "py",
    "pm",
    "ps",
    "pi",
    "yp",
    "yy",
    "ym",
  ],
  month_format_narrow => [
    "Y",
    "M",
    "M",
    "I",
    "P",
    "P",
    "P",
    "P",
    "P",
    "Y",
    "Y",
    "Y",
  ],
  month_format_wide => [
    "yep\N{U+00e9}",
    "muk\N{U+0169}i",
    "musap\N{U+00ed}ri",
    "ir\N{U+0169}d\N{U+00ed}",
    "p\N{U+00fa}",
    "p\N{U+00fa}-yep\N{U+00e9}",
    "p\N{U+00fa}-muk\N{U+0169}i",
    "p\N{U+00fa}-musap\N{U+00ed}ri",
    "p\N{U+00fa}-ir\N{U+0169}d\N{U+00ed}",
    "yep\N{U+00e9}-putima\N{U+00e3}",
    "yep\N{U+00e9}-yep\N{U+00e9}",
    "yep\N{U+00e9}-muk\N{U+0169}i",
  ],
  month_stand_alone_abbreviated => [
    "ye",
    "mk",
    "ms",
    "id",
    "pu",
    "py",
    "pm",
    "ps",
    "pi",
    "yp",
    "yy",
    "ym",
  ],
  month_stand_alone_narrow => [
    "Y",
    "M",
    "M",
    "I",
    "P",
    "P",
    "P",
    "P",
    "P",
    "Y",
    "Y",
    "Y",
  ],
  month_stand_alone_wide => [
    "yep\N{U+00e9}",
    "muk\N{U+0169}i",
    "musap\N{U+00ed}ri",
    "ir\N{U+0169}d\N{U+00ed}",
    "p\N{U+00fa}",
    "p\N{U+00fa}-yep\N{U+00e9}",
    "p\N{U+00fa}-muk\N{U+0169}i",
    "p\N{U+00fa}-musap\N{U+00ed}ri",
    "p\N{U+00fa}-ir\N{U+0169}d\N{U+00ed}",
    "yep\N{U+00e9}-putima\N{U+00e3}",
    "yep\N{U+00e9}-yep\N{U+00e9}",
    "yep\N{U+00e9}-muk\N{U+0169}i",
  ],
  name => "Nheengatu Colombia",
  native_language => "\N{U+00f1}engat\N{U+00fa}",
  native_name => "\N{U+00f1}engat\N{U+00fa} Kur\N{U+0169}biya",
  native_script => undef,
  native_territory => "Kur\N{U+0169}biya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "M1",
    "M2",
    "M3",
    "M4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "yep\N{U+00e9}s\N{U+00e1}wa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "muk\N{U+0169}isawa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "musap\N{U+00ed}risawa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "ir\N{U+0169}disawa musap\N{U+00ed}ri-yas\N{U+00ed}",
  ],
  quarter_stand_alone_abbreviated => [
    "M1",
    "M2",
    "M3",
    "M4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "yep\N{U+00e9}s\N{U+00e1}wa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "muk\N{U+0169}isawa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "musap\N{U+00ed}risawa musap\N{U+00ed}ri-yas\N{U+00ed}",
    "ir\N{U+0169}disawa musap\N{U+00ed}ri-yas\N{U+00ed}",
  ],
  script => undef,
  territory => "Colombia",
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => "44.1",
}
